;;; emacs.scm --- custom Guix packages for Emacs
;;;
;;; Copyright © 2019 Kyle Meyer <kyle@kyleam.com>
;;;
;;; This file is NOT part of GNU Guix.
;;;
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License as
;;; published by the Free Software Foundation, either version 3 of the
;;; License, or (at your option) any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;;; General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program.  If not, see
;;; <https://www.gnu.org/licenses/>.

(define-module (km-packages emacs)
  #:use-module (gnu packages)
  #:use-module (gnu packages base)
  #:use-module (gnu packages emacs-xyz)
  #:use-module (guix build-system emacs)
  #:use-module (guix build-system gnu)
  #:use-module (guix download)
  #:use-module (guix git-download)
  #:use-module ((guix licenses) #:prefix license:)
  #:use-module (guix packages))

(define-public emacs-org-board
  (package
    (name "emacs-org-board")
    (version "1018")
    (source (origin
              (method url-fetch)
              (uri (string-append
                    "https://github.com/scallywag/org-board/archive/"
                    version ".tar.gz"))
              (file-name (string-append name "-" version ".tar.gz"))
              (sha256
               (base32
                "1y3pjq5r0385dzz4wxmm3a97aqjfbngrysgl56l26aa293lhxxj0"))))
    (build-system emacs-build-system)
    (home-page "https://github.com/scallywag/org-board")
    (synopsis "TODO")
    (description "TODO")
    (license license:gpl3+)))

(define-public emacs-stan-mode
  (package
    (name "emacs-stan-mode")
    (version "9.2.0")
    (source (origin
              (method url-fetch)
              (uri (string-append
                    "https://github.com/stan-dev/stan-mode/archive/v"
                    version ".tar.gz"))
              (file-name (string-append name "-" version ".tar.gz"))
              (sha256
               (base32
                "075n4y886lb5qvq1rl9kizxb5rypl11ky10akpnxcv005gja4dkq"))))
    (build-system emacs-build-system)
    (arguments
     `(#:phases
       (modify-phases %standard-phases
         ;; Build server side using 'gnu-build-system'.
         (add-after 'unpack 'enter-lisp-dir
           (lambda _ (chdir "stan-mode") #t)))))
    (home-page "https://github.com/stan-dev/stan-mode")
    (synopsis "Major mode for editing Stan files")
    (description
     "Provides syntax highlighting, indentation, and imenu support for
Stan files.")
    (license license:gpl3+)))

;; TODO: Probably within Guix ledger package, but that was failing
;; when I tried to build it.  Look into.
(define-public emacs-ledger
  (package
    (name "emacs-ledger")
    (version "3.1.1")
    (source (origin
              (method url-fetch)
              (uri (string-append
                    "https://github.com/ledger/ledger-mode/archive/v"
                    version ".tar.gz"))
              (file-name (string-append name "-" version ".tar.gz"))
              (sha256
               (base32
                "0x6g808j6xjjxw29k0bfvbx9aagccx6608f6a66y7cxyi6zqf46b"))))
    (build-system emacs-build-system)
    (arguments
     '(#:exclude (delete "^[^/]*tests?\\.el$" %default-exclude)))
    (home-page "https://github.com/ledger/ledger-mode")
    (synopsis "Major mode for editing Ledger files")
    (description "Major mode for editing Ledger files")
    (license license:gpl2)))

(define-public emacs-ox-gfm
  (package
    (name "emacs-ox-gfm")
    (version "1.0")
    (source (origin
              (method url-fetch)
              (uri (string-append
                    "https://github.com/larstvei/ox-gfm/archive/v"
                    version ".tar.gz"))
              (file-name (string-append name "-" version ".tar.gz"))
              (sha256
               (base32
                "0jjznn30bv86a8nh3kqkcilsanplamrvgfji6w0fhwd38ihn2h8l"))))
    (build-system emacs-build-system)
    (home-page "https://github.com/larstvei/ox-gfm")
    (synopsis "Github Flavored Markdown Back-End for Org Export Engine ")
    (description "TODO")
    (license license:gpl3+)))
